@@ -1,29 +1,30 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* evolution-addressbook-export-list-folders.c
- *
- * Copyright (C) 2003 Ximian, Inc.
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- * Author: Gilbert Fang <gilbert.fang@sun.com>
+ *
+ * Authors:
+ *		Gilbert Fang <gilbert.fang@sun.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
 #include <config.h>
 
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <bonobo-activation/bonobo-activation.h>
 #include <libbonobo.h>
 #include <libgnome/libgnome.h>
@@ -40,12 +41,12 @@ action_list_folders_init (ActionContext * p_actctx)
 	FILE *outputfile = NULL;
 
 	if (!e_book_get_addressbooks (&addressbooks, NULL)) {
-		g_warning (_("Couldn't get list of addressbooks"));
+		g_warning (_("Couldn't get list of address books"));
 		exit (-1);
 	}
 
 	if (p_actctx->action_list_folders.output_file != NULL) {
-		if (!(outputfile = fopen (p_actctx->action_list_folders.output_file, "w"))) {
+		if (!(outputfile = g_fopen (p_actctx->action_list_folders.output_file, "w"))) {
 			g_warning (_("Can not open file"));
 			exit (-1);
 		}
