@@ -642,7 +642,7 @@ populate_widgets_from_alarm (Dialog *dialog)
 
 	/* Alarm options */
 	e_dialog_option_menu_set (dialog->action, *action, action_map);
-	action_selection_done_cb (GTK_MENU_SHELL (dialog->action), dialog);
+	action_selection_done_cb (GTK_MENU_SHELL (gtk_option_menu_get_menu (GTK_OPTION_MENU (dialog->action))), dialog);
 
 	switch (*action) {
 	case E_CAL_COMPONENT_ALARM_AUDIO:
@@ -863,7 +863,7 @@ setup_select_names (Dialog *dialog)
 	dialog->malarm_addresses =
 		GTK_WIDGET (e_name_selector_peek_section_entry (dialog->name_selector, section_name));
 	gtk_widget_show (dialog->malarm_addresses);
-	gtk_box_pack_end_defaults (GTK_BOX (dialog->malarm_address_group), dialog->malarm_addresses);
+	gtk_box_pack_end (GTK_BOX (dialog->malarm_address_group), dialog->malarm_addresses, TRUE, TRUE, 0);
 
 	g_signal_connect (G_OBJECT (dialog->malarm_addressbook), "clicked",
 			  G_CALLBACK (addressbook_clicked_cb), dialog);
