@@ -172,7 +172,7 @@ static void comp_editor_show_help (CompEditor *editor);
 static void setup_widgets (CompEditor *editor);
 
 static void real_edit_comp (CompEditor *editor, ECalComponent *comp);
-static gboolean real_send_comp (CompEditor *editor, ECalComponentItipMethod method);
+static gboolean real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms);
 static gboolean prompt_and_save_changes (CompEditor *editor, gboolean send);
 static void close_dialog (CompEditor *editor);
 
@@ -888,6 +888,7 @@ save_comp_with_send (CompEditor *editor)
 	CompEditorFlags flags;
 	gboolean send;
 	gboolean delegate;
+	gboolean strip_alarms = TRUE;
 
 	priv = editor->priv;
 
@@ -907,18 +908,18 @@ save_comp_with_send (CompEditor *editor)
 	if (!save_comp (editor))
 		return FALSE;
 
-	if ((delegate && !e_cal_get_save_schedules (priv->client)) || (send && send_component_dialog ((GtkWindow *) editor, priv->client, priv->comp, !priv->existing_org))) {
+	if ((delegate && !e_cal_get_save_schedules (priv->client)) || (send && send_component_dialog ((GtkWindow *) editor, priv->client, priv->comp, !priv->existing_org, &strip_alarms))) {
  		if ((itip_organizer_is_user (priv->comp, priv->client) || itip_sentby_is_user (priv->comp))) {
  			if (e_cal_component_get_vtype (priv->comp) == E_CAL_COMPONENT_JOURNAL)
-				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_PUBLISH);
+				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_PUBLISH, strip_alarms);
 			else
-				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST);
+				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST, strip_alarms);
 		} else {
-			if (!comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST))
+			if (!comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST, strip_alarms))
 				return FALSE;
 
 			if (delegate)
-				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REPLY);
+				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REPLY, strip_alarms);
 		}
  	}
 
@@ -1764,6 +1765,14 @@ comp_editor_class_init (CompEditorClass *class)
 			      G_TYPE_NONE, 0);
 }
 
+static void
+classification_changed_cb (GtkRadioAction *action, GtkRadioAction *current, CompEditor *editor)
+{
+	g_return_if_fail (IS_COMP_EDITOR (editor));
+
+	comp_editor_set_changed (editor, TRUE);
+}
+
 static void
 comp_editor_init (CompEditor *editor)
 {
@@ -1813,7 +1822,7 @@ comp_editor_init (CompEditor *editor)
 		action_group, classification_radio_entries,
 		G_N_ELEMENTS (classification_radio_entries),
 		E_CAL_COMPONENT_CLASS_PUBLIC,
-		NULL, NULL);  /* no callback */
+		G_CALLBACK (classification_changed_cb), editor);
 	action = e_attachment_bar_recent_action_new (
 		E_ATTACHMENT_BAR (priv->attachment_bar),
 		"attach-recent", _("Recent _Documents"));
@@ -2938,6 +2947,7 @@ fill_widgets (CompEditor *editor)
 {
 	CompEditorPrivate *priv;
 	GList *l;
+	GtkAction *action;
 
 	priv = editor->priv;
 
@@ -2952,8 +2962,13 @@ fill_widgets (CompEditor *editor)
 		g_slist_free (attachment_list);
 	}
 
+	action = comp_editor_get_action (editor, "classify-public");
+	g_signal_handlers_block_by_func (action, G_CALLBACK (classification_changed_cb), editor);
+
 	for (l = priv->pages; l != NULL; l = l->next)
 		comp_editor_page_fill_widgets (l->data, priv->comp);
+
+	g_signal_handlers_unblock_by_func (action, G_CALLBACK (classification_changed_cb), editor);
 }
 
 static void
@@ -3045,7 +3060,7 @@ get_users_from_memo_comp (ECalComponent *comp, GList **users)
 }
 
 static gboolean
-real_send_comp (CompEditor *editor, ECalComponentItipMethod method)
+real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms)
 {
 	CompEditorPrivate *priv;
 	CompEditorFlags flags;
@@ -3091,7 +3106,7 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 		if (!e_cal_component_has_attachments (priv->comp) 
 		 || e_cal_get_static_capability (priv->client, CAL_STATIC_CAPABILITY_CREATE_MESSAGES)) {
 		if (itip_send_comp (method, send_comp, priv->client,
-					NULL, NULL, users)) {
+					NULL, NULL, users, strip_alarms)) {
 			g_object_unref (send_comp);
 			return TRUE;
 		}
@@ -3112,7 +3127,7 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 		/* mime_attach_list is freed by itip_send_comp */
 		mime_attach_list = comp_editor_get_mime_attach_list (editor);
 		if (itip_send_comp (method, send_comp, priv->client,
-					NULL, mime_attach_list, users)) {
+					NULL, mime_attach_list, users, strip_alarms)) {
 			save_comp (editor);
 			g_object_unref (send_comp);
 			return TRUE;
@@ -3234,7 +3249,7 @@ comp_editor_delete_comp (CompEditor *editor)
  *
  **/
 gboolean
-comp_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method)
+comp_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms)
 {
 	CompEditorClass *class;
 
@@ -3243,7 +3258,7 @@ comp_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 	class = COMP_EDITOR_GET_CLASS (editor);
 
 	if (class->send_comp)
-		return class->send_comp (editor, method);
+		return class->send_comp (editor, method, strip_alarms);
 
 	return FALSE;
 }
