@@ -51,6 +51,7 @@ EAccountList *itip_addresses_get (void);
 EAccount *itip_addresses_get_default (void);
 
 gboolean itip_organizer_is_user (ECalComponent *comp, ECal *client);
+gboolean itip_organizer_is_user_ex (ECalComponent *comp, ECal *client, gboolean skip_cap_test);
 gboolean itip_sentby_is_user (ECalComponent *comp);
 
 const gchar *itip_strip_mailto (const gchar *address);
@@ -58,7 +59,7 @@ const gchar *itip_strip_mailto (const gchar *address);
 char *itip_get_comp_attendee (ECalComponent *comp, ECal *client);
 
 gboolean itip_send_comp (ECalComponentItipMethod method, ECalComponent *comp,
-			 ECal *client, icalcomponent *zones, GSList *attachments_list, GList *users);
+			 ECal *client, icalcomponent *zones, GSList *attachments_list, GList *users, gboolean strip_alarms);
 
 gboolean itip_publish_comp (ECal *client, gchar* uri, gchar* username,
 			    gchar* password, ECalComponent **pub_comp);
