@@ -1226,14 +1226,17 @@ efhd_format_secure(EMFormat *emf, CamelStream *stream, CamelMimePart *part, Came
 		pobj = (struct _smime_pobject *)em_format_html_add_pobject((EMFormatHTML *)emf, sizeof(*pobj), classid, part, efhd_xpkcs7mime_button);
 		pobj->valid = camel_cipher_validity_clone(valid);
 		pobj->object.free = efhd_xpkcs7mime_free;
-		camel_stream_printf(stream, "<td valign=top><object classid=\"%s\"></object></td><td width=100%% valign=top>", classid);
+		camel_stream_printf(stream, "<td valign=center><object classid=\"%s\"></object></td><td width=100%% valign=center>", classid);
 		g_free(classid);
 		if (valid->sign.status != CAMEL_CIPHER_VALIDITY_SIGN_NONE) {
-			camel_stream_printf(stream, "%s<br>", _(smime_sign_table[valid->sign.status].shortdesc));
+			camel_stream_printf (stream, "%s", _(smime_sign_table[valid->sign.status].shortdesc));
 		}
 
 		if (valid->encrypt.status != CAMEL_CIPHER_VALIDITY_ENCRYPT_NONE) {
-			camel_stream_printf(stream, "%s<br>", _(smime_encrypt_table[valid->encrypt.status].shortdesc));
+			if (valid->sign.status != CAMEL_CIPHER_VALIDITY_SIGN_NONE) {
+				camel_stream_printf (stream, "<br>");
+			}
+			camel_stream_printf (stream, "%s", _(smime_encrypt_table[valid->encrypt.status].shortdesc));
 		}
 
 		camel_stream_printf(stream, "</td></tr></table>");
@@ -2129,7 +2132,7 @@ type_ok:
 	}
 	
 	/* FIXME: How should I free the Bonobo_ServerInfo's ? */
-	g_list_foreach (components, CORBA_free, NULL);
+	g_list_foreach (components, (GFunc)CORBA_free, NULL);
 	g_list_free (components);
 	 
 	return component != NULL; 	 
@@ -2352,7 +2355,8 @@ efhd_update_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pob
 	EMFormatHTMLDisplay *efhd = (EMFormatHTMLDisplay *)efh;
 	struct _EMFormatHTMLDisplayPrivate *priv = efhd->priv;
 
-	e_attachment_bar_refresh (E_ATTACHMENT_BAR (priv->attachment_bar));
+	if (priv->attachment_bar)
+		e_attachment_bar_refresh (E_ATTACHMENT_BAR (priv->attachment_bar));
 
 	return TRUE;
 }
@@ -2435,7 +2439,7 @@ efhd_message_update_bar(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 	EMFormatHTMLDisplay *efhd = (EMFormatHTMLDisplay *) emf;
 	const char *classid = "attachment-bar-refresh";
 
-	if (efhd->nobar || efhd->priv->updated || !efhd->priv->attachment_bar)
+	if (efhd->nobar || efhd->priv->updated)
 		return;
 
 	efhd->priv->files = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
