@@ -1,11 +1,21 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-cell-text.c: Text cell renderer.
- * Copyright 1999, 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
  *
  * Authors:
- *   Miguel de Icaza <miguel@ximian.com>
- *          Chris Lahey <clahey@ximian.com>
+ *		Miguel de Icaza <miguel@ximian.com>
+ *      Chris Lahey <clahey@ximian.com>
  *
  * A lot of code taken from:
  *
@@ -19,19 +29,8 @@
  *
  * Author: Federico Mena <federico@nuclecu.unam.mx>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -613,21 +612,8 @@ build_layout (ECellTextView *text_view, int row, const char *text, gint width)
 	pango_layout_set_width (layout, width * PANGO_SCALE);
 	pango_layout_set_wrap (layout, PANGO_WRAP_CHAR);
 
-	if (pango_layout_get_line_count (layout) > 1) {
-		PangoLayoutLine *line = pango_layout_get_line (layout, 0);
-		gchar *line_text = g_strdup (pango_layout_get_text (layout));
-		gchar *last_char = g_utf8_find_prev_char (line_text, line_text + line->length - 1);
-		while (last_char && pango_layout_get_line_count (layout) > 1) {
-			gchar *new_text;
-			last_char = g_utf8_find_prev_char (line_text, last_char);
-			if (last_char)
-				*last_char = '\0';
-			new_text = g_strconcat (line_text, "...", NULL);
-			pango_layout_set_text (layout, new_text, -1);
-			g_free (new_text);
-		}
-		g_free (line_text);
-	}
+	pango_layout_set_ellipsize (layout, PANGO_ELLIPSIZE_END);
+	pango_layout_set_height (layout, 0);
 
 	switch (ect->justify) {
 	case GTK_JUSTIFY_RIGHT:
